#! python
# -*- coding: utf-8 -*-
# (c) 2006 Juergen Riegel 

class ModelTemplate:
    def Generate(self):
        print("Generate() needs to be implemented in a Template class!")

